@@ -103,7 +103,8 @@ def _init():
         load_dotenv(dotenv_path=_env_file_path, override=True)
 
     ## Options for loggers
-    _configs_dict = {
+    _config = {
+        'level': 'INFO',
         'use_color': True,
         'use_icon': False,
         'use_backtrace': True,
@@ -127,33 +128,48 @@ def _init():
         'json_err_log_filename': '{app_name}.json.err.log'
     }
 
-    ## Loading configs from file, if it's exits:
-    _yaml_configs_file_path = os.path.join(_current_dir, 'configs', 'logger.yaml')
-    if os.path.isfile(_yaml_configs_file_path):
+    ## Loading config from file, if it's exits:
+    _configs_dir = os.path.join(_current_dir, 'configs')
+    _yaml_config_file_path = os.path.join(_configs_dir, 'logger.yaml')
+    if not os.path.isfile(_yaml_config_file_path):
+        _yaml_config_file_path = os.path.join(_configs_dir, 'logger.yml')
+    _json_config_file_path = os.path.join(_configs_dir, 'logger.json')
+
+    if os.path.isfile(_yaml_config_file_path):
         try:
-            with open(_yaml_configs_file_path, 'r') as _yaml_configs_file:
-                _configs_dict = yaml.safe_load(_yaml_configs_file)['logger']
+            with open(_yaml_config_file_path, 'r', encoding='utf8') as _yaml_config_file:
+                _config = yaml.safe_load(_yaml_config_file)['logger']
         except Exception:
-            logger.exception(f"Failed to load '{_yaml_configs_file_path}' configs file.")
+            logger.exception(f"Failed to load '{_yaml_config_file_path}' yaml config file.")
+            exit(2)
+    elif os.path.isfile(_json_config_file_path):
+        try:
+            with open(_json_config_file_path, 'r', encoding='utf8') as _json_config_file:
+                _config = json.load(_json_config_file)['logger']
+        except Exception:
+            logger.exception(f"Failed to load '{_json_config_file_path}' json config file.")
             exit(2)
 
-    _configs_dict['is_debug'] = False
-    _configs_dict['level'] = 'INFO'
-    _configs_dict['use_diagnose'] = False
+    if not 'level' in _config:
+        _config['level'] = 'INFO'
+    _config['is_debug'] = False
+    _config['use_diagnose'] = False
 
     ## Checking environment for DEBUG option:
     _ENV = str(os.getenv('ENV')).strip().lower()
     _DEBUG = str(os.getenv('DEBUG')).strip().lower()
     if (_DEBUG == 'true') or ((_ENV == 'development') and ((_DEBUG == 'none') or (_DEBUG == ''))):
-        _configs_dict['is_debug'] = True
+        _config['is_debug'] = True
         os.environ['DEBUG'] = 'true'
 
-    if _configs_dict['is_debug']:
-        _configs_dict['level'] = 'DEBUG'
-        _configs_dict['use_diagnose'] = True
+    if _config['is_debug'] and (_config['level'] != 'TRACE'):
+        _config['level'] = 'DEBUG'
 
-    if _configs_dict['use_icon']:
-        _configs_dict['std_format_str'] = _configs_dict['std_format_str'].replace('lvlname:<5', 'level.icon:<4')
+    if (_config['level'] == 'DEBUG') or (_config['level'] == 'TRACE'):
+        _config['use_diagnose'] = True
+
+    if _config['use_icon']:
+        _config['std_format_str'] = _config['std_format_str'].replace('lvlname:<5', 'level.icon:<4')
 
     # if _USE_COLOR:
     #     ## Checking terminal could support xterm colors:
@@ -164,15 +180,15 @@ def _init():
     ## Initializing std stream log handler:
     logger.remove()
     logger.add(_std_sink,
-                level=_configs_dict['level'],
-                format=_configs_dict['std_format_str'],
-                colorize=_configs_dict['use_color'],
+                level=_config['level'],
+                format=_config['std_format_str'],
+                colorize=_config['use_color'],
                 filter=_add_lvlname,
-                backtrace=_configs_dict['use_backtrace'],
-                diagnose=_configs_dict['use_diagnose'])
+                backtrace=_config['use_backtrace'],
+                diagnose=_config['use_diagnose'])
 
     ## Checking log file handlers enabled or not:
-    if _configs_dict['use_log_file'] or _configs_dict['use_log_json']:
+    if _config['use_log_file'] or _config['use_log_json']:
         ## Setting 'APP_NAME':
         _APP_NAME = os.path.splitext(os.path.basename(sys.argv[0]))[0]
         if os.getenv('APP_NAME') and os.getenv('APP_NAME').strip():
@@ -185,8 +201,8 @@ def _init():
         if os.getenv('LOGS_DIR') and os.getenv('LOGS_DIR').strip():
             _LOGS_DIR = os.getenv('LOGS_DIR').strip()
         else:
-            if ('logs_dir' in _configs_dict) and _configs_dict['logs_dir'].strip():
-                _LOGS_DIR = _configs_dict['logs_dir'].strip()
+            if ('logs_dir' in _config) and _config['logs_dir'].strip():
+                _LOGS_DIR = _config['logs_dir'].strip()
             else:
                 _LOGS_DIR = os.path.join(_current_dir, 'logs')
                 logger.debug(f"Not found 'LOGS_DIR' environment variable, changed to '{_LOGS_DIR}' local directory.")
@@ -205,87 +221,87 @@ def _init():
             logger.success(f"Successfully created '{_LOGS_DIR}' directory!")
 
         ## Setting up log file handlers:
-        _rotate_when = datetime.time(_configs_dict['rotate_when']['at_hour'], _configs_dict['rotate_when']['at_minute'], _configs_dict['rotate_when']['at_second'])
-        if _configs_dict['use_log_file']:
+        _rotate_when = datetime.time(_config['rotate_when']['at_hour'], _config['rotate_when']['at_minute'], _config['rotate_when']['at_second'])
+        if _config['use_log_file']:
             ## Initializing log file handler:
-            _out_rotator = Rotator(size=_configs_dict['rotate_file_size'], at=_rotate_when)
-            _log_file_path = os.path.join(_LOGS_DIR, _configs_dict['all_log_filename'].format(app_name=_APP_NAME))
+            _out_rotator = Rotator(size=_config['rotate_file_size'], at=_rotate_when)
+            _log_file_path = os.path.join(_LOGS_DIR, _config['all_log_filename'].format(app_name=_APP_NAME))
             logger.add(_log_file_path,
-                        level=_configs_dict['level'],
-                        format=_configs_dict['file_format_str'],
+                        level=_config['level'],
+                        format=_config['file_format_str'],
                         rotation=_out_rotator.should_rotate,
-                        retention=_configs_dict['backup_file_count'],
-                        encoding=_configs_dict['file_encoding'],
+                        retention=_config['backup_file_count'],
+                        encoding=_config['file_encoding'],
                         enqueue=True,
-                        backtrace=_configs_dict['use_backtrace'],
-                        diagnose=_configs_dict['use_diagnose'])
+                        backtrace=_config['use_backtrace'],
+                        diagnose=_config['use_diagnose'])
 
             ## Initializing error log file handler:
-            _err_rotator = Rotator(size=_configs_dict['rotate_file_size'], at=_rotate_when)
-            _log_file_path = os.path.join(_LOGS_DIR, _configs_dict['err_log_filename'].format(app_name=_APP_NAME))
+            _err_rotator = Rotator(size=_config['rotate_file_size'], at=_rotate_when)
+            _log_file_path = os.path.join(_LOGS_DIR, _config['err_log_filename'].format(app_name=_APP_NAME))
             logger.add(_log_file_path,
                         level='WARNING',
-                        format=_configs_dict['file_format_str'],
+                        format=_config['file_format_str'],
                         rotation=_err_rotator.should_rotate,
-                        retention=_configs_dict['backup_file_count'],
-                        encoding=_configs_dict['file_encoding'],
+                        retention=_config['backup_file_count'],
+                        encoding=_config['file_encoding'],
                         enqueue=True,
-                        backtrace=_configs_dict['use_backtrace'],
-                        diagnose=_configs_dict['use_diagnose'])
+                        backtrace=_config['use_backtrace'],
+                        diagnose=_config['use_diagnose'])
 
-        if _configs_dict['use_log_json']:
-            _json_out_rotator = Rotator(size=_configs_dict['rotate_file_size'], at=_rotate_when)
-            _json_err_rotator = Rotator(size=_configs_dict['rotate_file_size'], at=_rotate_when)
+        if _config['use_log_json']:
+            _json_out_rotator = Rotator(size=_config['rotate_file_size'], at=_rotate_when)
+            _json_err_rotator = Rotator(size=_config['rotate_file_size'], at=_rotate_when)
 
-            if _configs_dict['use_custom_json']:
+            if _config['use_custom_json']:
                 ## Initializing json log file handler:
-                _log_file_path = os.path.join(_LOGS_DIR, _configs_dict['json_all_log_filename'].format(app_name=_APP_NAME))
+                _log_file_path = os.path.join(_LOGS_DIR, _config['json_all_log_filename'].format(app_name=_APP_NAME))
                 logger.add(_log_file_path,
-                            level=_configs_dict['level'],
+                            level=_config['level'],
                             format=_custom_json_formatter,
                             rotation=_json_out_rotator.should_rotate,
-                            retention=_configs_dict['backup_file_count'],
-                            encoding=_configs_dict['file_encoding'],
+                            retention=_config['backup_file_count'],
+                            encoding=_config['file_encoding'],
                             enqueue=True,
-                            backtrace=_configs_dict['use_backtrace'],
-                            diagnose=_configs_dict['use_diagnose'])
+                            backtrace=_config['use_backtrace'],
+                            diagnose=_config['use_diagnose'])
 
                 ## Initializing json error log file handler:
-                _log_file_path = os.path.join(_LOGS_DIR, _configs_dict['json_err_log_filename'].format(app_name=_APP_NAME))
+                _log_file_path = os.path.join(_LOGS_DIR, _config['json_err_log_filename'].format(app_name=_APP_NAME))
                 logger.add(_log_file_path,
                             level='WARNING',
                             format=_custom_json_formatter,
                             rotation=_json_err_rotator.should_rotate,
-                            retention=_configs_dict['backup_file_count'],
-                            encoding=_configs_dict['file_encoding'],
+                            retention=_config['backup_file_count'],
+                            encoding=_config['file_encoding'],
                             enqueue=True,
-                            backtrace=_configs_dict['use_backtrace'],
-                            diagnose=_configs_dict['use_diagnose'])
+                            backtrace=_config['use_backtrace'],
+                            diagnose=_config['use_diagnose'])
             else:
                 ## Initializing json log file handler:
-                _log_file_path = os.path.join(_LOGS_DIR, _configs_dict['json_all_log_filename'].format(app_name=_APP_NAME))
+                _log_file_path = os.path.join(_LOGS_DIR, _config['json_all_log_filename'].format(app_name=_APP_NAME))
                 logger.add(_log_file_path,
-                            level=_configs_dict['level'],
+                            level=_config['level'],
                             format='',
                             serialize=True,
                             rotation=_json_out_rotator.should_rotate,
-                            retention=_configs_dict['backup_file_count'],
-                            encoding=_configs_dict['file_encoding'],
+                            retention=_config['backup_file_count'],
+                            encoding=_config['file_encoding'],
                             enqueue=True,
-                            backtrace=_configs_dict['use_backtrace'],
-                            diagnose=_configs_dict['use_diagnose'])
+                            backtrace=_config['use_backtrace'],
+                            diagnose=_config['use_diagnose'])
 
                 ## Initializing json error log file handler:
-                _log_file_path = os.path.join(_LOGS_DIR, _configs_dict['json_err_log_filename'].format(app_name=_APP_NAME))
+                _log_file_path = os.path.join(_LOGS_DIR, _config['json_err_log_filename'].format(app_name=_APP_NAME))
                 logger.add(_log_file_path,
                             level='WARNING',
                             format='',
                             serialize=True,
                             rotation=_json_err_rotator.should_rotate,
-                            retention=_configs_dict['backup_file_count'],
-                            encoding=_configs_dict['file_encoding'],
+                            retention=_config['backup_file_count'],
+                            encoding=_config['file_encoding'],
                             enqueue=True,
-                            backtrace=_configs_dict['use_backtrace'],
-                            diagnose=_configs_dict['use_diagnose'])
+                            backtrace=_config['use_backtrace'],
+                            diagnose=_config['use_diagnose'])
 
 _init()
